@@ -236,7 +236,7 @@ class Node {
     if (funcBuffer_) {
       destroy_(funcBuffer_);
     }
-  };
+  }
   /**
    * Make this node depends on nodes. This is not concurrency safe.
    *
@@ -413,7 +413,7 @@ class DISPENSO_DLL_ACCESS SubgraphT {
   SubgraphT() = delete;
   SubgraphT(const SubgraphT<N>&) = delete;
   SubgraphT<N>& operator=(const SubgraphT<N>&) = delete;
-  SubgraphT(SubgraphT<N>&& other)
+  SubgraphT(SubgraphT<N>&& other) noexcept
       : graph_(other.graph_),
         nodes_(std::move(other.nodes_)),
         allocator_(std::move(other.allocator_)) {}
@@ -486,7 +486,7 @@ class DISPENSO_DLL_ACCESS SubgraphT {
 
   static constexpr size_t kNodeSizeP2 = detail::nextPow2(sizeof(NodeType));
 
-  explicit SubgraphT<N>(GraphT<N>* graph) : graph_(graph), nodes_(), allocator_(getAllocator()) {}
+  explicit SubgraphT(GraphT<N>* graph) : graph_(graph), nodes_(), allocator_(getAllocator()) {}
 
   inline void removeNodeFromBiPropSet(Node* /* node */) {}
   void removeNodeFromBiPropSet(BiPropNode* node) {
@@ -502,14 +502,14 @@ class DISPENSO_DLL_ACCESS SubgraphT {
   static void releaseAllocator(NoLockPoolAllocator* ptr);
 
   GraphT<N>* graph_;
-#if defined(_WIN32)
+#if defined(_WIN32) && !defined(__MINGW32__)
 #pragma warning(push)
 #pragma warning(disable : 4251)
 #endif
   std::vector<N*> nodes_;
 
   PoolPtr allocator_;
-#if defined(_WIN32)
+#if defined(_WIN32) && !defined(__MINGW32__)
 #pragma warning(pop)
 #endif
 
@@ -527,7 +527,7 @@ class DISPENSO_DLL_ACCESS GraphT {
   /**
    * Create empty graph.
    **/
-  GraphT<N>() {
+  GraphT() {
     subgraphs_.push_back(SubgraphType(this));
   }
   /**
@@ -537,7 +537,7 @@ class DISPENSO_DLL_ACCESS GraphT {
   /**
    * Move assignment operator
    **/
-  GraphT<N>& operator=(GraphT&& other);
+  GraphT<N>& operator=(GraphT&& other) noexcept;
   /**
    * Construct a <code>NodeType</code> with a valid functor. This node is created into subgraph 0.
    * This is not concurrency safe.
@@ -664,12 +664,12 @@ class DISPENSO_DLL_ACCESS GraphT {
  private:
   static constexpr size_t kSubgraphSizeP2 = detail::nextPow2(sizeof(SubgraphType));
 
-#if defined(_WIN32)
+#if defined(_WIN32) && !defined(__MINGW32__)
 #pragma warning(push)
 #pragma warning(disable : 4251)
 #endif
   std::deque<SubgraphT<N>> subgraphs_;
-#if defined(_WIN32)
+#if defined(_WIN32) && !defined(__MINGW32__)
 #pragma warning(pop)
 #endif
 
