@@ -5,14 +5,16 @@
  * LICENSE file in the root directory of this source tree.
  */
 
-#if defined DISPENSO_DEBUG
-#include <iostream>
-#endif // DISPENSO_DEBUG
 #include <dispenso/detail/quanta.h>
 #include <dispenso/thread_pool.h>
 
+#if defined DISPENSO_DEBUG
+#include <iostream>
+#endif // DISPENSO_DEBUG
+
 namespace dispenso {
 
+namespace {
 size_t getAdjustedThreadCount(size_t requested) {
   static const size_t maxThreads = []() {
     size_t maxT = std::numeric_limits<size_t>::max();
@@ -40,6 +42,7 @@ size_t getAdjustedThreadCount(size_t requested) {
 
   return std::min(requested, maxThreads);
 }
+} // namespace
 
 void ThreadPool::PerThreadData::setThread(std::thread&& t) {
   thread_ = std::move(t);
