@@ -1082,8 +1082,8 @@ std::string printVec(const std::vector<int>& vec) {
 
 #define EXPECT_VEC_SUM(vec, num)                                                        \
   do {                                                                                  \
-    long maxV = (num) - 1;                                                              \
-    long result = 0;                                                                    \
+    int64_t maxV = (num) - 1;                                                           \
+    int64_t result = 0;                                                                 \
     for (auto& v : vec) {                                                               \
       result += *v;                                                                     \
     }                                                                                   \
@@ -1093,8 +1093,8 @@ std::string printVec(const std::vector<int>& vec) {
 
 #define EXPECT_VEC_SUM_MINUS(vec, num, minus)                   \
   do {                                                          \
-    long maxV = (num) - 1;                                      \
-    long result = 0;                                            \
+    int64_t maxV = (num) - 1;                                   \
+    int64_t result = 0;                                         \
     for (auto& v : vec) {                                       \
       result += *v;                                             \
     }                                                           \
